# web-api: status

get several information about the server

call via `/status` or `/status/<what>`.  

available values for `<what>` are:

* `server`    - read more about [server status](status_server.md)
* `crawlers`  - read more about [crawlers status](status_crawlers.md)
* `blacklist` - read more about [blacklist status](status_blacklist.md)
